/* Open the browser window for the directory specified on the command line.
 * If no directory is specified the current directory is opened.
 * Open can also open apps and files (launching the correct app
 * against the requested file) -- it's the browser that does this anyway.
 *
 * For some reason if you want to open the root of, for example, your boot volume,
 * you can't say "open /boot" or "open /boot/". "open /boot/." seems to work though.
 *
 * Open is dr7 specific. It's based on Eric Knight's comments in BeDevTalk about the
 * internals of the browser. The dr8 browser should have standard support for
 * external requests of refs to be opened.
 *
 * 14 July 1996, by Duncan Wilcox (duncan@mclink.it  http://www.mclink.it/personal/MC2199).
 *
 * I hereby donate this program in the Public Domain.
 *
 */
int main(int argc, char **argv)
{
	char		curr[256];
	record_ref	ref;
	BVolume		vol = boot_volume();
	BDirectory	*dir;

	dir = new BDirectory;
	if(dir)
	{
		/* First switch to the current directory...
		 */
		vol.GetRootDirectory(dir);
		getcwd(curr, sizeof(curr));
		if(dir->GetRefForPath(curr, &ref) == B_NO_ERROR)
			dir->SetRef(ref);

		/* ... then switch to the requested directory
		 * (this way relative paths also work)
		 */
		if(dir->GetRefForPath(argc == 1 ? "." : argv[1], &ref) == B_NO_ERROR)
		{
			/* Create BMessenger to comunicate with Browser
			 */
			BMessenger *br = new BMessenger('SHRK');
			if(br)
			{
				if(br->Error() == B_NO_ERROR)
				{
					/* As in Eric Knight's (devsupport@be.com) message in BeDevTalk on Jul 9
					 */
					BMessage *msg = new BMessage('Bopn');
					if(msg)
					{
						msg->AddRef("refs", ref);
						br->SendMessage(msg);
						delete msg;
					}
					else
						printf("open failed: not enough memory\n");
				}
				else
					printf("open failed: BMessenger reports error %d\n", br->Error());
			
				delete br;
			}
			else
				printf("open failed: not enough memory\n");
		}
		else
			printf("open failed: invalid path\n");

		delete dir;
	}
	else
		printf("open failed: not enough memory\n");

	return 0;
}
